pub enum IdentityFileConvertError {
FailedToWriteOutput(Error),
NoIdentities {
filename: Option<String>,
},
}Expand description
Errors returned when converting an identity file to a recipients file.
Variants
FailedToWriteOutput(Error)
An I/O error occurred while writing out a recipient corresponding to an identity in this file.
NoIdentities
The identity file contains no identities, and thus cannot be used to produce a recipients file.